==> design-system-core-0.1.0.tgz: package/stories/forms/TextInput.stories.js <==
import classNames from 'classnames'

import '../../scss/components/forms/inputs.scss'
import '../../scss/components/forms/input-label.scss'
import '../../scss/components/forms/error-message.scss'

/**
 * The standard form text input, shown here with a label, hint, and where applicable an error message
 *
 * **Note:** Make sure to include a label for each input used
 * */
export default {
  title: 'Components/Form/TextInput',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    readonly: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    readonly: false,
    error: false,
  },
}

const TextTemplate = ({ disabled, readonly, error }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_text = classNames('rpf-input rpf-input-text', {
    'rpf-input--error': error,
  })

  return `
    <div class="${classnames_wrapper}">
      <div class="${classnames_label}">
        <label for="name">What is your name?</label>
        <div class="rpf-label__hint" for="name">Please enter your first and last names</div>
      </div>
      <input type="text" name="name" class="${classnames_text}"${
    disabled || readonly ? ' disabled' : ''
  } value="Joe Bloggs">
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">info</span>Error: Your name is required</div>'
          : ''
      }
    </div>
  `
}

export const Default = TextTemplate.bind({})
Default.args = {}

export const Error = TextTemplate.bind({})
Error.args = {
  error: true,
}

export const Readonly = TextTemplate.bind({})
Readonly.args = {
  readonly: true,
}

export const Disabled = TextTemplate.bind({})
Disabled.args = {
  disabled: true,
}

==> design-system-core-0.1.3.tgz: package/stories/forms/TextInput.stories.js <==
import classNames from 'classnames'

import '../../scss/components/forms/inputs.scss'
import '../../scss/components/forms/input-label.scss'
import '../../scss/components/forms/error-message.scss'

/**
 * The standard form text input, shown here with a label, hint, and where applicable an error message
 *
 * **Note:** Make sure to include a label for each input used
 * */
export default {
  title: 'Components/Form/TextInput',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    readonly: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    readonly: false,
    error: false,
    fullWidth: false,
  },
}

const TextTemplate = ({ disabled, readonly, error, fullWidth }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_text = classNames('rpf-input rpf-input-text', {
    'rpf-input--error': error,
    'rpf-input--full-width': fullWidth,
  })

  return `
    <div class="${classnames_wrapper}">
      <label for="name" class="${classnames_label}">
        What is your name?
        <small class="rpf-label__hint">Please enter your first and last names</small>
      </label>
      <input type="text" name="name" class="${classnames_text}"${
    disabled || readonly ? ' disabled' : ''
  } value="Joe Bloggs">
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">info</span>Error: Your name is required</div>'
          : ''
      }
    </div>
  `
}

export const Default = TextTemplate.bind({})
Default.args = {}

export const Error = TextTemplate.bind({})
Error.args = {
  error: true,
}

export const Readonly = TextTemplate.bind({})
Readonly.args = {
  readonly: true,
}

export const Disabled = TextTemplate.bind({})
Disabled.args = {
  disabled: true,
}


export const FullWidth = TextTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}
